@@ -1,10 +1,10 @@
 use std::time::Duration;
-use stretto::{Cache, DefaultKeyBuilder};
+use stretto::{AsyncCache, DefaultKeyBuilder};
 
 #[tokio::main]
 async fn main() {
-    let c: Cache<&str, &str, DefaultKeyBuilder> =
-        Cache::new(12960, 1e6 as i64, DefaultKeyBuilder::default()).unwrap();
+    let c: AsyncCache<&str, &str, DefaultKeyBuilder> =
+        AsyncCache::new(12960, 1e6 as i64, DefaultKeyBuilder::default()).unwrap();
 
     // set a value with a cost of 1
     c.insert("a", "a", 1).await;
@@ -22,13 +22,15 @@ async fn main() {
     // release the value
     v.release(); // or drop(v)
 
-    // when we get the value, we will get a ValueRef, which contains a RwLockWriteGuard
-    // so when we finish use this value, we must release the ValueRefMut
-    let mut v = c.get_mut(&"a").unwrap();
-    v.write("aa");
-    assert_eq!(v.value(), &"aa");
-    // release the value
-    v.release(); // or use drop(v);
+    // lock will be auto released when out of scope
+    {
+        // when we get the value, we will get a ValueRef, which contains a RwLockWriteGuard
+        // so when we finish use this value, we must release the ValueRefMut
+        let mut v = c.get_mut(&"a").unwrap();
+        v.write("aa");
+        assert_eq!(v.value(), &"aa");
+        // release the value
+    }
 
     // if you just want to do one operation
     let v = c.get_mut(&"a").unwrap();
