@@ -18,13 +18,15 @@ fn main() {
     assert_eq!(v.value(), &"a");
     v.release();
 
-    // when we get the value, we will get a ValueRef, which contains a RwLockWriteGuard
-    // so when we finish use this value, we must release the ValueRefMut
-    let mut v = c.get_mut(&"a").unwrap();
-    v.write("aa");
-    assert_eq!(v.value(), &"aa");
-    // release the value
-    v.release(); // or use drop(v);
+    // lock will be auto released when out of scope
+    {
+        // when we get the value, we will get a ValueRef, which contains a RwLockWriteGuard
+        // so when we finish use this value, we must release the ValueRefMut
+        let mut v = c.get_mut(&"a").unwrap();
+        v.write("aa");
+        assert_eq!(v.value(), &"aa");
+        // release the value
+    }
 
     // if you just want to do one operation
     let v = c.get_mut(&"a").unwrap();
